==> igniteui-webcomponents-spreadsheet-3.5.0.tgz: package/esm5/lib/CustomDOMEventProxy.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { CanvasGestureDOMEventProxy } from "igniteui-webcomponents-core";
import { markType } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
var CustomDOMEventProxy = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CustomDOMEventProxy, _super);
    function CustomDOMEventProxy(a, b, c) {
        var _this = _super.call(this, a, b, c) || this;
        _this._d8 = null;
        return _this;
    }
    CustomDOMEventProxy.prototype.cu = function (a) {
        _super.prototype.cu.call(this, a);
        if (!this.ae && a.stopPropagation != null) {
            a.stopPropagation();
        }
    };
    CustomDOMEventProxy.prototype.cv = function (a) {
        if (this._d8 != null && this._d8(a)) {
            return;
        }
        _super.prototype.cv.call(this, a);
    };
    CustomDOMEventProxy.$t = markType(CustomDOMEventProxy, 'CustomDOMEventProxy', CanvasGestureDOMEventProxy.$);
    return CustomDOMEventProxy;
}(CanvasGestureDOMEventProxy));
export { CustomDOMEventProxy };

==> igniteui-webcomponents-spreadsheet-4.6.0.tgz: package/esm5/lib/CustomDOMEventProxy.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { CanvasGestureDOMEventProxy } from "igniteui-webcomponents-core";
import { markType } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
var CustomDOMEventProxy = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomDOMEventProxy, _super);
    function CustomDOMEventProxy(a, b, c) {
        var _this = _super.call(this, a, b, c) || this;
        _this._d8 = null;
        return _this;
    }
    CustomDOMEventProxy.prototype.cu = function (a) {
        _super.prototype.cu.call(this, a);
        if (!this.ae && a.stopPropagation != null) {
            a.stopPropagation();
        }
    };
    CustomDOMEventProxy.prototype.cv = function (a) {
        if (this._d8 != null && this._d8(a)) {
            return;
        }
        _super.prototype.cv.call(this, a);
    };
    CustomDOMEventProxy.$t = markType(CustomDOMEventProxy, 'CustomDOMEventProxy', CanvasGestureDOMEventProxy.$);
    return CustomDOMEventProxy;
}(CanvasGestureDOMEventProxy));
export { CustomDOMEventProxy };
